@@ -3,8 +3,8 @@ Allows connecting any object to any other object and unifying the interface
 between all the objects.
 """
 __version_info__ = {
-    'major': 0,
-    'minor': 4,
+    'major': 1,
+    'minor': 1,
     'micro': 0,
     'releaselevel': 'final',
     'serial': 1
@@ -90,10 +90,11 @@ try:
 
         Copied from django.contrib.admin
         """
+        from .settings import SKIP_APPS
         from django.conf import settings
 
         for app in settings.INSTALLED_APPS:
-            if app != 'contentrelations':
+            if app != 'contentrelations' and app not in SKIP_APPS:
                 discover(app)
 
 except ImportError:
