@@ -4,7 +4,8 @@ from django.conf import settings
 
 DEFAULT_SETTINGS = {
     'SETUP_RESOURCES': [],
-    'JS_PREFIX': 'static/',
+    'JS_PREFIX': '',
+    'SKIP_APPS': []
 }
 
 USER_SETTINGS = DEFAULT_SETTINGS.copy()
